// 
//   Script to select parts, put them in a set, and move them. 
//
//   Select a model (if only one model is present, it will be
//   selected automatically)

var m = Model.Select("Select a model");

//   Allocate and clear a flag

var my_flag = AllocateFlag();
m.ClearFlag(my_flag);

//   Other variables that need to be visible to the functions below

var setID_start;      //  Set ID will be first free above this number
var x_trans;          //  Translation distance for selected parts
var num_selected = 0; //  Number of parts

//   Add code here to create a new window

var w = new Window("My menu", 0.8, 0.95, 0.05, 0.20);

//   Add code here to place the following widgets in the window:
//
//   1. Label for text box "Translation distance" (to describe 2.)
//   2. Text box containing a blank string (will be used for x_trans)
//   3. Label for text box "Set ID " (to describe 3.)
//   4. Text box containing a blank string (will be used for setID_start)
//   5. A button "Select Parts"
//   6. A button "Apply"
//   7. A button "Quit"

var label_dist    = new Widget(w, Widget.LABEL,    1, 20,  1,  7, "Distance");
var input_dist    = new Widget(w, Widget.TEXTBOX, 25, 45,  1,  7, "");
var label_setID   = new Widget(w, Widget.LABEL,    1, 20,  8, 14, "Set ID");
var input_setID   = new Widget(w, Widget.TEXTBOX, 25, 45,  8, 14, "");
var select_button = new Widget(w, Widget.BUTTON,  25, 45, 15, 21, "Select");
var apply_button  = new Widget(w, Widget.BUTTON,   1, 20, 22, 28, "Apply");
var quit_button   = new Widget(w, Widget.BUTTON,  25, 45, 22, 28, "Quit");

//  Actions for buttons

select_button.onClick = SelectParts;
apply_button.onClick = MoveParts;           
quit_button.onClick = Exit;

//   Add call to Show to display the menu
w.Show();


////////////////////////////////////////////////////////////////
//
//   Add a function here to select parts (using Part.Select)

function SelectParts()
{
   Part.Select(my_flag, "Select parts to move");
}

/////////////////////////////////////////////////////////////////
//
//   Function that performs the actions when Apply is pressed

function MoveParts()
{

//   Check that the user has input something
   if (!input_dist.text || !input_setID) return;

//   Take the input data from the text boxes

   x_trans     = parseFloat(input_dist.text);
   setID_start = parseInt(input_setID.text);

//   Count the selected parts

   num_selected = 0;
   var p = Part.First(m);
   while (p)            
   {
      if (p.Flagged(my_flag))
      {
         Message("Selected part " + p.pid);             
         num_selected++;
      }
      p = p.Next();
   }

   Message("Number of selected parts = " + num_selected);

//   Add code to check that >0 parts were selected

   if (num_selected == 0)
   {
      Error ("No parts were selected!");
      return;
   }

//
//   Find the first free set ID (starting from setID_start)

   var set_id = setID_start;
   while(Set.GetFromID(m, set_id, Set.PART)) set_id++;
 
//   Add code to create the part set using ID set_id, and 
//       add the flagged parts to it
   var s = new Set(m, set_id, Set.PART);
   s.AddFlagged(my_flag);

//   Propagate flag

   m.PropagateFlag(my_flag);

//   Loop through all the nodes

   var n = Node.First(m);
   while (n)
   {
//   (Add code to increase x-coord by x_trans if node is flagged)
      if (n.Flagged(my_flag)) n.x = n.x + x_trans;
      n = n.Next();
   }

//   Redraw the new model and exit //

   m.UpdateGraphics();
   View.Ac();
   Exit();
}
