// 
//  Javascript to find maximum horizontal displacement of any node at any time
//

SetCurrentModel(1);                // Assume we are working with Model 1
var nnode  = GetNumberOf(NODE);    // Find number of nodes in model
var nstate = GetNumberOf(STATE);   // Get number of time-states in results file

var dhmax = new Array();           // Max displacement is an array (per node) 
for (j=1; j<=nnode; j++) dhmax[j] = 0.0; // Initialize the array to zero

//////////////////////////////////////////////////////////////////////////
//
//  First, we need to find the maximum that occurs for any time, for each node
//
//  Loop through states

for (istate=1; istate<=nstate; istate++)   
{
   SetCurrentState(istate);
   Message("...processing state " + istate);

//  Loop through nodes, finding max displacement

   for (j=1; j<=nnode; j++)
   {
      var dx1 = GetData(DX, NODE, j);
      var dy1 = GetData(DY, NODE, j);
      var disp = Math.sqrt(dx1*dx1 + dy1*dy1);
      dhmax[j] = Math.max(dhmax[j],disp);
   }

//  Next state
}

//  Create new data component for plotting

icomp = CreateUbinComponent("Horiz percent" , U_NODE, U_SCALAR, REPLACE); 

//////////////////////////////////////////////////////////////////////////
//
//  Now we can calculate current horizontal displacement as a percentage 
//  of the maximum
//
//  Loop through states

for (istate=1; istate<=nstate; istate++)   
{
   SetCurrentState(istate);
   Message("...processing state " + istate);

//  Loop through nodes, calculating displacement as a percentage

   for (j=1; j<=nnode; j++)
   {
      var dx1 = GetData(DX, NODE, j);
      var dy1 = GetData(DY, NODE, j);
      var disp = Math.sqrt(dx1*dx1 + dy1*dy1);
      var result = 0.0;
      if (dhmax[j] > 0.0) result = 100.0*disp/dhmax[j];
      PutUbinData(icomp, NODE, j, 0, result);       // store data for plotting 
   }

//  Next state
}

Exit();
